Components › User — Stisla

# User

## Users

Components relating to users, lists of users and so on.

Follow
Hasan Basri
Web Developer

Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.

Follow Hasan On
View Posts

#### Users

View All
Hasan Basri
Web Developer
Kusnaedi
Mobile Developer
Bagus Dwi Cahya
UI Designer
Wildan Ahdian
Project Manager
Deden Febriansyah
IT Support
Posts
187
Followers
6,8K
Following
2,1K
Hasan Basri
Web Developer

Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.

#### Authors

#### Comments

- Approved
  Rizal Fakhri
  Yesterday
  Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.
  View
  Edit
  Trash
- Pending
  Bambang Uciha
  Yesterday
  Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.
  View
  Edit
  Trash
- Approved
  Ujang Maman
  Yesterday
  Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident
  View
  Edit
  Trash

#### User Progress

- Rizal Fakhri
  Web Developer
  30%
  Detail
- Irwansyah Saputra
  Web Developer
  67%
  Detail
- Hasan Basri
  Web Developer
  45%
  Detail

#### User Details

- Rizal Fakhri
  Web Developer
  1,239
  Posts
  10K
  Followers
  2,312
  Following
- Irwansyah Saputra
  Web Developer
  4,872
  Posts
  43K
  Followers
  1,290
  Following
- Hasan Basri
  Web Developer
  1,821
  Posts
  14K
  Followers
  2,891
  Following